@@ -11,6 +11,8 @@
 
 #ifdef PCI_OS_WINDOWS
 #include "compat/getopt.h"
+#else
+#include <unistd.h>
 #endif
 
 #define PCIUTILS_VERSION PCILIB_VERSION
@@ -20,6 +22,7 @@ extern const char program_name[];
 void die(char *msg, ...) NONRET PCI_PRINTF(1,2);
 void *xmalloc(unsigned int howmuch);
 void *xrealloc(void *ptr, unsigned int howmuch);
+char *xstrdup(char *str);
 int parse_generic_option(int i, struct pci_access *pacc, char *optarg);
 
 #ifdef PCI_HAVE_PM_INTEL_CONF
